==> angelssmelting_0.3.5.zip: angelssmelting_0.3.5/prototypes/buildings/strand-casting-machine.lua <==
data:extend(
{
  {
    type = "item",
    name = "strand-casting-machine",
	icons = {
		{
			icon = "__angelssmelting__/graphics/icons/strand-casting-machine.png",
		},
		{
			icon = "__angelspetrochem__/graphics/icons/num_1.png",
			tint = {r = 0.8, g = 0.8, b = 0.8, a = 0.5},
			scale = 0.32,
			shift = {-12, -12},
		}
	},
	flags = {"goes-to-quickbar"},
    subgroup = "angels-strand-casting-machine",
    order = "a[strand-casting-machine]",
    place_result = "strand-casting-machine",
    stack_size = 10,
   },
   {
    type = "assembling-machine",
    name = "strand-casting-machine",
	icons = {
		{
			icon = "__angelssmelting__/graphics/icons/strand-casting-machine.png",
		},
		{
			icon = "__angelspetrochem__/graphics/icons/num_1.png",
			tint = {r = 0.8, g = 0.8, b = 0.8, a = 0.5},
			scale = 0.32,
			shift = {-12, -12},
		}
	},
	flags = {"placeable-neutral","player-creation"},
    minable = {mining_time = 1, result = "strand-casting-machine"},
	fast_replaceable_group = "strand-casting-machine",
    max_health = 300,
	corpse = "big-remnants",
    dying_explosion = "medium-explosion",
    collision_box = {{-2.4, -2.4}, {2.4, 2.4}},
    selection_box = {{-2.5, -2.5}, {2.5, 2.5}},
    module_specification =
    {
      module_slots = 2
    },
    allowed_effects = {"consumption", "speed", "productivity", "pollution"},
    crafting_categories = {"strand-casting"},
    crafting_speed = 1,
    energy_source =
    {
      type = "electric",
      usage_priority = "secondary-input",
      emissions = 0.03 / 3.5
    },
    energy_usage = "150kW",
    ingredient_count = 2,
    animation ={
        width = 448,
        height = 448,
        frame_count = 24,
		animation_speed = 0.5,
		scale = 0.5,
		shift = {0, 0},
		stripes = {
			{
				filename = "__angelssmelting__/graphics/entity/strand-casting-machine/strand-casting-1.png",
				width_in_frames = 4,
				height_in_frames = 3,
			},
			{
				filename = "__angelssmelting__/graphics/entity/strand-casting-machine/strand-casting-2.png",
				width_in_frames = 4,
				height_in_frames = 3,
			},	
		}
    },
    fluid_boxes =
    {
      {
        production_type = "input",
        --pipe_picture = assembler3pipepictures(),
        pipe_covers = pipecoverspictures(),
        base_area = 10,
        base_level = -1,
        pipe_connections = {{ type="input", position = {-1, 3} }}
      },
      {
        production_type = "input",
        --pipe_picture = assembler3pipepictures(),
        pipe_covers = pipecoverspictures(),
        base_area = 10,
        base_level = -1,
        pipe_connections = {{ type="input", position = {1, 3} }}
      },
      {
        production_type = "input",
        --pipe_picture = assembler3pipepictures(),
        pipe_covers = pipecoverspictures(),
        base_area = 10,
        base_level = -1,
        pipe_connections = {{ type="input", position = {-1, -3} }}
      },
      {
        production_type = "output",
        --pipe_picture = assembler3pipepictures(),
        pipe_covers = pipecoverspictures(),
        base_level = 1,
        pipe_connections = {{ position = {1, -3} }}
      }
    },
    vehicle_impact_sound =  { filename = "__base__/sound/car-metal-impact.ogg", volume = 0.65 },
    working_sound =
    {
      sound = { filename = "__angelssmelting__/sound/strand-casting-machine.ogg" },
	  idle_sound = { filename = "__base__/sound/idle1.ogg", volume = 0.6 },
      apparent_volume = 2.5,
    },
	},
    {
    type = "item",
    name = "strand-casting-machine-2",
	icons = {
		{
			icon = "__angelssmelting__/graphics/icons/strand-casting-machine.png",
		},
		{
			icon = "__angelspetrochem__/graphics/icons/num_2.png",
			tint = {r = 0.8, g = 0.8, b = 0.8, a = 0.5},
			scale = 0.32,
			shift = {-12, -12},
		}
	},
	flags = {"goes-to-quickbar"},
    subgroup = "angels-strand-casting-machine",
    order = "b[strand-casting-machine-2]",
    place_result = "strand-casting-machine-2",
    stack_size = 10,
    },
    {
    type = "assembling-machine",
    name = "strand-casting-machine-2",
	icons = {
		{
			icon = "__angelssmelting__/graphics/icons/strand-casting-machine.png",
		},
		{
			icon = "__angelspetrochem__/graphics/icons/num_2.png",
			tint = {r = 0.8, g = 0.8, b = 0.8, a = 0.5},
			scale = 0.32,
			shift = {-12, -12},
		}
	},
	flags = {"placeable-neutral","player-creation"},
    minable = {mining_time = 1, result = "strand-casting-machine-2"},
	fast_replaceable_group = "strand-casting-machine",
    max_health = 300,
	corpse = "big-remnants",
    dying_explosion = "medium-explosion",
    collision_box = {{-2.4, -2.4}, {2.4, 2.4}},
    selection_box = {{-2.5, -2.5}, {2.5, 2.5}},
    module_specification =
    {
      module_slots = 2
    },
    allowed_effects = {"consumption", "speed", "productivity", "pollution"},
    crafting_categories = {"strand-casting"},
    crafting_speed = 1.5,
    energy_source =
    {
      type = "electric",
      usage_priority = "secondary-input",
      emissions = 0.03 / 3.5
    },
    energy_usage = "200kW",
    ingredient_count = 4,
    animation ={
        width = 448,
        height = 448,
        frame_count = 24,
		animation_speed = 0.5,
		scale = 0.5,
		shift = {0, 0},
		stripes = {
			{
				filename = "__angelssmelting__/graphics/entity/strand-casting-machine/strand-casting-1.png",
				width_in_frames = 4,
				height_in_frames = 3,
			},
			{
				filename = "__angelssmelting__/graphics/entity/strand-casting-machine/strand-casting-2.png",
				width_in_frames = 4,
				height_in_frames = 3,
			},	
		}
    },
    fluid_boxes =
    {
      {
        production_type = "input",
        --pipe_picture = assembler3pipepictures(),
        pipe_covers = pipecoverspictures(),
        base_area = 10,
        base_level = -1,
        pipe_connections = {{ type="input", position = {-1, 3} }}
      },
      {
        production_type = "input",
        --pipe_picture = assembler3pipepictures(),
        pipe_covers = pipecoverspictures(),
        base_area = 10,
        base_level = -1,
        pipe_connections = {{ type="input", position = {1, 3} }}
      },
      {
        production_type = "input",
        --pipe_picture = assembler3pipepictures(),
        pipe_covers = pipecoverspictures(),
        base_area = 10,
        base_level = -1,
        pipe_connections = {{ type="input", position = {-1, -3} }}
      },
      {
        production_type = "output",
        --pipe_picture = assembler3pipepictures(),
        pipe_covers = pipecoverspictures(),
        base_level = 1,
        pipe_connections = {{ position = {1, -3} }}
      }
    },
    vehicle_impact_sound =  { filename = "__base__/sound/car-metal-impact.ogg", volume = 0.65 },
    working_sound =
    {
      sound = { filename = "__angelssmelting__/sound/strand-casting-machine.ogg" },
	  idle_sound = { filename = "__base__/sound/idle1.ogg", volume = 0.6 },
      apparent_volume = 2.5,
    },
	},
    {
    type = "item",
    name = "strand-casting-machine-3",
	icons = {
		{
			icon = "__angelssmelting__/graphics/icons/strand-casting-machine.png",
		},
		{
			icon = "__angelspetrochem__/graphics/icons/num_3.png",
			tint = {r = 0.8, g = 0.8, b = 0.8, a = 0.5},
			scale = 0.32,
			shift = {-12, -12},
		}
	},
	flags = {"goes-to-quickbar"},
    subgroup = "angels-strand-casting-machine",
    order = "c[strand-casting-machine-3]",
    place_result = "strand-casting-machine-3",
    stack_size = 10,
    },
    {
    type = "assembling-machine",
    name = "strand-casting-machine-3",
	icons = {
		{
			icon = "__angelssmelting__/graphics/icons/strand-casting-machine.png",
		},
		{
			icon = "__angelspetrochem__/graphics/icons/num_3.png",
			tint = {r = 0.8, g = 0.8, b = 0.8, a = 0.5},
			scale = 0.32,
			shift = {-12, -12},
		}
	},
	flags = {"placeable-neutral","player-creation"},
    minable = {mining_time = 1, result = "strand-casting-machine-3"},
	fast_replaceable_group = "strand-casting-machine",
    max_health = 300,
	corpse = "big-remnants",
    dying_explosion = "medium-explosion",
    collision_box = {{-2.4, -2.4}, {2.4, 2.4}},
    selection_box = {{-2.5, -2.5}, {2.5, 2.5}},
    module_specification =
    {
      module_slots = 2
    },
    allowed_effects = {"consumption", "speed", "productivity", "pollution"},
    crafting_categories = {"strand-casting"},
    crafting_speed = 2,
    energy_source =
    {
      type = "electric",
      usage_priority = "secondary-input",
      emissions = 0.03 / 3.5
    },
    energy_usage = "250kW",
    ingredient_count = 6,
    animation ={
        width = 448,
        height = 448,
        frame_count = 24,
		animation_speed = 0.5,
		scale = 0.5,
		shift = {0, 0},
		stripes = {
			{
				filename = "__angelssmelting__/graphics/entity/strand-casting-machine/strand-casting-1.png",
				width_in_frames = 4,
				height_in_frames = 3,
			},
			{
				filename = "__angelssmelting__/graphics/entity/strand-casting-machine/strand-casting-2.png",
				width_in_frames = 4,
				height_in_frames = 3,
			},	
		}
    },
    fluid_boxes =
    {
      {
        production_type = "input",
        --pipe_picture = assembler3pipepictures(),
        pipe_covers = pipecoverspictures(),
        base_area = 10,
        base_level = -1,
        pipe_connections = {{ type="input", position = {-1, 3} }}
      },
      {
        production_type = "input",
        --pipe_picture = assembler3pipepictures(),
        pipe_covers = pipecoverspictures(),
        base_area = 10,
        base_level = -1,
        pipe_connections = {{ type="input", position = {1, 3} }}
      },
      {
        production_type = "input",
        --pipe_picture = assembler3pipepictures(),
        pipe_covers = pipecoverspictures(),
        base_area = 10,
        base_level = -1,
        pipe_connections = {{ type="input", position = {-1, -3} }}
      },
      {
        production_type = "output",
        --pipe_picture = assembler3pipepictures(),
        pipe_covers = pipecoverspictures(),
        base_level = 1,
        pipe_connections = {{ position = {1, -3} }}
      }
    },
    vehicle_impact_sound =  { filename = "__base__/sound/car-metal-impact.ogg", volume = 0.65 },
    working_sound =
    {
      sound = { filename = "__angelssmelting__/sound/strand-casting-machine.ogg" },
	  idle_sound = { filename = "__base__/sound/idle1.ogg", volume = 0.6 },
      apparent_volume = 2.5,
    },
	},
	{
    type = "item",
    name = "strand-casting-machine-4",
	icons = {
		{
			icon = "__angelssmelting__/graphics/icons/strand-casting-machine.png",
		},
		{
			icon = "__angelspetrochem__/graphics/icons/num_4.png",
			tint = {r = 0.8, g = 0.8, b = 0.8, a = 0.5},
			scale = 0.32,
			shift = {-12, -12},
		}
	},
	flags = {"goes-to-quickbar"},
    subgroup = "angels-strand-casting-machine",
    order = "d[strand-casting-machine-4]",
    place_result = "strand-casting-machine-4",
    stack_size = 10,
    },	
	{
    type = "assembling-machine",
    name = "strand-casting-machine-4",
	icons = {
		{
			icon = "__angelssmelting__/graphics/icons/strand-casting-machine.png",
		},
		{
			icon = "__angelspetrochem__/graphics/icons/num_4.png",
			tint = {r = 0.8, g = 0.8, b = 0.8, a = 0.5},
			scale = 0.32,
			shift = {-12, -12},
		}
	},
	flags = {"placeable-neutral","player-creation"},
    minable = {mining_time = 1, result = "strand-casting-machine-4"},
	fast_replaceable_group = "strand-casting-machine",
    max_health = 300,
	corpse = "big-remnants",
    dying_explosion = "medium-explosion",
    collision_box = {{-2.4, -2.4}, {2.4, 2.4}},
    selection_box = {{-2.5, -2.5}, {2.5, 2.5}},
    module_specification =
    {
      module_slots = 2
    },
    allowed_effects = {"consumption", "speed", "productivity", "pollution"},
    crafting_categories = {"strand-casting"},
    crafting_speed = 3,
    energy_source =
    {
      type = "electric",
      usage_priority = "secondary-input",
      emissions = 0.03 / 3.5
    },
    energy_usage = "250kW",
    ingredient_count = 6,
    animation ={
        width = 448,
        height = 448,
        frame_count = 24,
		animation_speed = 0.5,
		scale = 0.5,
		shift = {0, 0},
		stripes = {
			{
				filename = "__angelssmelting__/graphics/entity/strand-casting-machine/strand-casting-1.png",
				width_in_frames = 4,
				height_in_frames = 3,
			},
			{
				filename = "__angelssmelting__/graphics/entity/strand-casting-machine/strand-casting-2.png",
				width_in_frames = 4,
				height_in_frames = 3,
			},	
		}
    },
    fluid_boxes =
    {
      {
        production_type = "input",
        --pipe_picture = assembler3pipepictures(),
        pipe_covers = pipecoverspictures(),
        base_area = 10,
        base_level = -1,
        pipe_connections = {{ type="input", position = {-1, 3} }}
      },
      {
        production_type = "input",
        --pipe_picture = assembler3pipepictures(),
        pipe_covers = pipecoverspictures(),
        base_area = 10,
        base_level = -1,
        pipe_connections = {{ type="input", position = {1, 3} }}
      },
      {
        production_type = "input",
        --pipe_picture = assembler3pipepictures(),
        pipe_covers = pipecoverspictures(),
        base_area = 10,
        base_level = -1,
        pipe_connections = {{ type="input", position = {-1, -3} }}
      },
      {
        production_type = "output",
        --pipe_picture = assembler3pipepictures(),
        pipe_covers = pipecoverspictures(),
        base_level = 1,
        pipe_connections = {{ position = {1, -3} }}
      }
    },
    vehicle_impact_sound =  { filename = "__base__/sound/car-metal-impact.ogg", volume = 0.65 },
    working_sound =
    {
      sound = { filename = "__angelssmelting__/sound/strand-casting-machine.ogg" },
	  idle_sound = { filename = "__base__/sound/idle1.ogg", volume = 0.6 },
      apparent_volume = 2.5,
    },
	},
}
)

==> angelssmelting_0.4.3.zip: angelssmelting_0.4.3/prototypes/buildings/strand-casting-machine.lua <==
data:extend(
{
  {
    type = "item",
    name = "strand-casting-machine",
	icons = {
		{
			icon = "__angelssmelting__/graphics/icons/strand-casting-machine.png",
		},
		{
			icon = "__angelspetrochem__/graphics/icons/num_1.png",
			tint = {r = 0.8, g = 0.8, b = 0.8, a = 0.5},
			scale = 0.32,
			shift = {-12, -12},
		}
	},
	icon_size = 32,
	flags = {"goes-to-quickbar"},
    subgroup = "angels-strand-casting-machine",
    order = "a[strand-casting-machine]",
    place_result = "strand-casting-machine",
    stack_size = 10,
   },
   {
    type = "assembling-machine",
    name = "strand-casting-machine",
	icons = {
		{
			icon = "__angelssmelting__/graphics/icons/strand-casting-machine.png",
		},
		{
			icon = "__angelspetrochem__/graphics/icons/num_1.png",
			tint = {r = 0.8, g = 0.8, b = 0.8, a = 0.5},
			scale = 0.32,
			shift = {-12, -12},
		}
	},
	icon_size = 32,
	flags = {"placeable-neutral","player-creation"},
    minable = {mining_time = 1, result = "strand-casting-machine"},
	fast_replaceable_group = "strand-casting-machine",
    max_health = 300,
	corpse = "big-remnants",
    dying_explosion = "medium-explosion",
    collision_box = {{-2.4, -2.4}, {2.4, 2.4}},
    selection_box = {{-2.5, -2.5}, {2.5, 2.5}},
    module_specification =
    {
      module_slots = 2
    },
    allowed_effects = {"consumption", "speed", "productivity", "pollution"},
    crafting_categories = {"strand-casting"},
    crafting_speed = 1,
    energy_source =
    {
      type = "electric",
      usage_priority = "secondary-input",
      emissions = 0.03 / 3.5
    },
    energy_usage = "150kW",
    ingredient_count = 2,
    animation ={
        width = 448,
        height = 448,
        frame_count = 24,
		animation_speed = 0.5,
		scale = 0.5,
		shift = {0, 0},
		stripes = {
			{
				filename = "__angelssmelting__/graphics/entity/strand-casting-machine/strand-casting-1.png",
				width_in_frames = 4,
				height_in_frames = 3,
			},
			{
				filename = "__angelssmelting__/graphics/entity/strand-casting-machine/strand-casting-2.png",
				width_in_frames = 4,
				height_in_frames = 3,
			},	
		}
    },
    fluid_boxes =
    {
      {
        production_type = "input",
        --pipe_picture = assembler3pipepictures(),
        pipe_covers = pipecoverspictures(),
        base_area = 10,
        base_level = -1,
        pipe_connections = {{ type="input", position = {-1, 3} }}
      },
      {
        production_type = "input",
        --pipe_picture = assembler3pipepictures(),
        pipe_covers = pipecoverspictures(),
        base_area = 10,
        base_level = -1,
        pipe_connections = {{ type="input", position = {1, 3} }}
      },
      {
        production_type = "input",
        --pipe_picture = assembler3pipepictures(),
        pipe_covers = pipecoverspictures(),
        base_area = 10,
        base_level = -1,
        pipe_connections = {{ type="input", position = {-1, -3} }}
      },
      {
        production_type = "output",
        --pipe_picture = assembler3pipepictures(),
        pipe_covers = pipecoverspictures(),
        base_level = 1,
        pipe_connections = {{ position = {1, -3} }}
      }
    },
    vehicle_impact_sound =  { filename = "__base__/sound/car-metal-impact.ogg", volume = 0.65 },
    working_sound =
    {
      sound = { filename = "__angelssmelting__/sound/strand-casting-machine.ogg" },
	  idle_sound = { filename = "__base__/sound/idle1.ogg", volume = 0.6 },
      apparent_volume = 2.5,
    },
	},
    {
    type = "item",
    name = "strand-casting-machine-2",
	icons = {
		{
			icon = "__angelssmelting__/graphics/icons/strand-casting-machine.png",
		},
		{
			icon = "__angelspetrochem__/graphics/icons/num_2.png",
			tint = {r = 0.8, g = 0.8, b = 0.8, a = 0.5},
			scale = 0.32,
			shift = {-12, -12},
		}
	},
	icon_size = 32,
	flags = {"goes-to-quickbar"},
    subgroup = "angels-strand-casting-machine",
    order = "b[strand-casting-machine-2]",
    place_result = "strand-casting-machine-2",
    stack_size = 10,
    },
    {
    type = "assembling-machine",
    name = "strand-casting-machine-2",
	icons = {
		{
			icon = "__angelssmelting__/graphics/icons/strand-casting-machine.png",
		},
		{
			icon = "__angelspetrochem__/graphics/icons/num_2.png",
			tint = {r = 0.8, g = 0.8, b = 0.8, a = 0.5},
			scale = 0.32,
			shift = {-12, -12},
		}
	},
	icon_size = 32,
	flags = {"placeable-neutral","player-creation"},
    minable = {mining_time = 1, result = "strand-casting-machine-2"},
	fast_replaceable_group = "strand-casting-machine",
    max_health = 300,
	corpse = "big-remnants",
    dying_explosion = "medium-explosion",
    collision_box = {{-2.4, -2.4}, {2.4, 2.4}},
    selection_box = {{-2.5, -2.5}, {2.5, 2.5}},
    module_specification =
    {
      module_slots = 2
    },
    allowed_effects = {"consumption", "speed", "productivity", "pollution"},
    crafting_categories = {"strand-casting"},
    crafting_speed = 1.5,
    energy_source =
    {
      type = "electric",
      usage_priority = "secondary-input",
      emissions = 0.03 / 3.5
    },
    energy_usage = "200kW",
    ingredient_count = 4,
    animation ={
        width = 448,
        height = 448,
        frame_count = 24,
		animation_speed = 0.5,
		scale = 0.5,
		shift = {0, 0},
		stripes = {
			{
				filename = "__angelssmelting__/graphics/entity/strand-casting-machine/strand-casting-1.png",
				width_in_frames = 4,
				height_in_frames = 3,
			},
			{
				filename = "__angelssmelting__/graphics/entity/strand-casting-machine/strand-casting-2.png",
				width_in_frames = 4,
				height_in_frames = 3,
			},	
		}
    },
    fluid_boxes =
    {
      {
        production_type = "input",
        --pipe_picture = assembler3pipepictures(),
        pipe_covers = pipecoverspictures(),
        base_area = 10,
        base_level = -1,
        pipe_connections = {{ type="input", position = {-1, 3} }}
      },
      {
        production_type = "input",
        --pipe_picture = assembler3pipepictures(),
        pipe_covers = pipecoverspictures(),
        base_area = 10,
        base_level = -1,
        pipe_connections = {{ type="input", position = {1, 3} }}
      },
      {
        production_type = "input",
        --pipe_picture = assembler3pipepictures(),
        pipe_covers = pipecoverspictures(),
        base_area = 10,
        base_level = -1,
        pipe_connections = {{ type="input", position = {-1, -3} }}
      },
      {
        production_type = "output",
        --pipe_picture = assembler3pipepictures(),
        pipe_covers = pipecoverspictures(),
        base_level = 1,
        pipe_connections = {{ position = {1, -3} }}
      }
    },
    vehicle_impact_sound =  { filename = "__base__/sound/car-metal-impact.ogg", volume = 0.65 },
    working_sound =
    {
      sound = { filename = "__angelssmelting__/sound/strand-casting-machine.ogg" },
	  idle_sound = { filename = "__base__/sound/idle1.ogg", volume = 0.6 },
      apparent_volume = 2.5,
    },
	},
    {
    type = "item",
    name = "strand-casting-machine-3",
	icons = {
		{
			icon = "__angelssmelting__/graphics/icons/strand-casting-machine.png",
		},
		{
			icon = "__angelspetrochem__/graphics/icons/num_3.png",
			tint = {r = 0.8, g = 0.8, b = 0.8, a = 0.5},
			scale = 0.32,
			shift = {-12, -12},
		}
	},
	icon_size = 32,
	flags = {"goes-to-quickbar"},
    subgroup = "angels-strand-casting-machine",
    order = "c[strand-casting-machine-3]",
    place_result = "strand-casting-machine-3",
    stack_size = 10,
    },
    {
    type = "assembling-machine",
    name = "strand-casting-machine-3",
	icons = {
		{
			icon = "__angelssmelting__/graphics/icons/strand-casting-machine.png",
		},
		{
			icon = "__angelspetrochem__/graphics/icons/num_3.png",
			tint = {r = 0.8, g = 0.8, b = 0.8, a = 0.5},
			scale = 0.32,
			shift = {-12, -12},
		}
	},
	icon_size = 32,
	flags = {"placeable-neutral","player-creation"},
    minable = {mining_time = 1, result = "strand-casting-machine-3"},
	fast_replaceable_group = "strand-casting-machine",
    max_health = 300,
	corpse = "big-remnants",
    dying_explosion = "medium-explosion",
    collision_box = {{-2.4, -2.4}, {2.4, 2.4}},
    selection_box = {{-2.5, -2.5}, {2.5, 2.5}},
    module_specification =
    {
      module_slots = 2
    },
    allowed_effects = {"consumption", "speed", "productivity", "pollution"},
    crafting_categories = {"strand-casting"},
    crafting_speed = 2,
    energy_source =
    {
      type = "electric",
      usage_priority = "secondary-input",
      emissions = 0.03 / 3.5
    },
    energy_usage = "250kW",
    ingredient_count = 6,
    animation ={
        width = 448,
        height = 448,
        frame_count = 24,
		animation_speed = 0.5,
		scale = 0.5,
		shift = {0, 0},
		stripes = {
			{
				filename = "__angelssmelting__/graphics/entity/strand-casting-machine/strand-casting-1.png",
				width_in_frames = 4,
				height_in_frames = 3,
			},
			{
				filename = "__angelssmelting__/graphics/entity/strand-casting-machine/strand-casting-2.png",
				width_in_frames = 4,
				height_in_frames = 3,
			},	
		}
    },
    fluid_boxes =
    {
      {
        production_type = "input",
        --pipe_picture = assembler3pipepictures(),
        pipe_covers = pipecoverspictures(),
        base_area = 10,
        base_level = -1,
        pipe_connections = {{ type="input", position = {-1, 3} }}
      },
      {
        production_type = "input",
        --pipe_picture = assembler3pipepictures(),
        pipe_covers = pipecoverspictures(),
        base_area = 10,
        base_level = -1,
        pipe_connections = {{ type="input", position = {1, 3} }}
      },
      {
        production_type = "input",
        --pipe_picture = assembler3pipepictures(),
        pipe_covers = pipecoverspictures(),
        base_area = 10,
        base_level = -1,
        pipe_connections = {{ type="input", position = {-1, -3} }}
      },
      {
        production_type = "output",
        --pipe_picture = assembler3pipepictures(),
        pipe_covers = pipecoverspictures(),
        base_level = 1,
        pipe_connections = {{ position = {1, -3} }}
      }
    },
    vehicle_impact_sound =  { filename = "__base__/sound/car-metal-impact.ogg", volume = 0.65 },
    working_sound =
    {
      sound = { filename = "__angelssmelting__/sound/strand-casting-machine.ogg" },
	  idle_sound = { filename = "__base__/sound/idle1.ogg", volume = 0.6 },
      apparent_volume = 2.5,
    },
	},
	{
    type = "item",
    name = "strand-casting-machine-4",
	icons = {
		{
			icon = "__angelssmelting__/graphics/icons/strand-casting-machine.png",
		},
		{
			icon = "__angelspetrochem__/graphics/icons/num_4.png",
			tint = {r = 0.8, g = 0.8, b = 0.8, a = 0.5},
			scale = 0.32,
			shift = {-12, -12},
		}
	},
	icon_size = 32,
	flags = {"goes-to-quickbar"},
    subgroup = "angels-strand-casting-machine",
    order = "d[strand-casting-machine-4]",
    place_result = "strand-casting-machine-4",
    stack_size = 10,
    },	
	{
    type = "assembling-machine",
    name = "strand-casting-machine-4",
	icons = {
		{
			icon = "__angelssmelting__/graphics/icons/strand-casting-machine.png",
		},
		{
			icon = "__angelspetrochem__/graphics/icons/num_4.png",
			tint = {r = 0.8, g = 0.8, b = 0.8, a = 0.5},
			scale = 0.32,
			shift = {-12, -12},
		}
	},
	icon_size = 32,
	flags = {"placeable-neutral","player-creation"},
    minable = {mining_time = 1, result = "strand-casting-machine-4"},
	fast_replaceable_group = "strand-casting-machine",
    max_health = 300,
	corpse = "big-remnants",
    dying_explosion = "medium-explosion",
    collision_box = {{-2.4, -2.4}, {2.4, 2.4}},
    selection_box = {{-2.5, -2.5}, {2.5, 2.5}},
    module_specification =
    {
      module_slots = 2
    },
    allowed_effects = {"consumption", "speed", "productivity", "pollution"},
    crafting_categories = {"strand-casting"},
    crafting_speed = 3,
    energy_source =
    {
      type = "electric",
      usage_priority = "secondary-input",
      emissions = 0.03 / 3.5
    },
    energy_usage = "250kW",
    ingredient_count = 6,
    animation ={
        width = 448,
        height = 448,
        frame_count = 24,
		animation_speed = 0.5,
		scale = 0.5,
		shift = {0, 0},
		stripes = {
			{
				filename = "__angelssmelting__/graphics/entity/strand-casting-machine/strand-casting-1.png",
				width_in_frames = 4,
				height_in_frames = 3,
			},
			{
				filename = "__angelssmelting__/graphics/entity/strand-casting-machine/strand-casting-2.png",
				width_in_frames = 4,
				height_in_frames = 3,
			},	
		}
    },
    fluid_boxes =
    {
      {
        production_type = "input",
        --pipe_picture = assembler3pipepictures(),
        pipe_covers = pipecoverspictures(),
        base_area = 10,
        base_level = -1,
        pipe_connections = {{ type="input", position = {-1, 3} }}
      },
      {
        production_type = "input",
        --pipe_picture = assembler3pipepictures(),
        pipe_covers = pipecoverspictures(),
        base_area = 10,
        base_level = -1,
        pipe_connections = {{ type="input", position = {1, 3} }}
      },
      {
        production_type = "input",
        --pipe_picture = assembler3pipepictures(),
        pipe_covers = pipecoverspictures(),
        base_area = 10,
        base_level = -1,
        pipe_connections = {{ type="input", position = {-1, -3} }}
      },
      {
        production_type = "output",
        --pipe_picture = assembler3pipepictures(),
        pipe_covers = pipecoverspictures(),
        base_level = 1,
        pipe_connections = {{ position = {1, -3} }}
      }
    },
    vehicle_impact_sound =  { filename = "__base__/sound/car-metal-impact.ogg", volume = 0.65 },
    working_sound =
    {
      sound = { filename = "__angelssmelting__/sound/strand-casting-machine.ogg" },
	  idle_sound = { filename = "__base__/sound/idle1.ogg", volume = 0.6 },
      apparent_volume = 2.5,
    },
	},
}
)
